Contribute
**********

Any contribution is welcome! Feel free to add further oversampling techniques, functionalities, features or fix bugs:

    * fork the GitHub repository at http://github.com/gykovacs/smote_variants,
    * open a discussion on GitHub,
    * or contact me at gyuriofkovacs@gmail.com.
